summaryrefslogtreecommitdiff
path: root/TAO
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>1999-05-03 21:45:55 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>1999-05-03 21:45:55 +0000
commitf3ae0a9525c3f36e5feb09fe7a6b2d47fba0c98c (patch)
tree76175be331b8bce5dcf8bcdf6e1c486dd9c606c9 /TAO
parente414a62a9688cc5ee4ddc2f15ce8a598b616303b (diff)
downloadATCD-f3ae0a9525c3f36e5feb09fe7a6b2d47fba0c98c.tar.gz
Modified to use GIOP_Server_Request instead of IIOP_Server_Request
since the implementation was GIOP-specific, not IIOP-specific.
Diffstat (limited to 'TAO')
-rw-r--r--TAO/tao/Connect.cpp6
-rw-r--r--TAO/tao/GIOP_Server_Request.cpp (renamed from TAO/tao/IIOP_Server_Request.cpp)56
-rw-r--r--TAO/tao/GIOP_Server_Request.h (renamed from TAO/tao/IIOP_Server_Request.h)30
-rw-r--r--TAO/tao/GIOP_Server_Request.i (renamed from TAO/tao/UIOP_Server_Request.i)24
-rw-r--r--TAO/tao/IIOP_Server_Request.i78
-rw-r--r--TAO/tao/Makefile444
-rw-r--r--TAO/tao/TAO.dsp6
-rw-r--r--TAO/tao/TAO_Static.dsp6
-rw-r--r--TAO/tao/UIOP_Connect.cpp6
-rw-r--r--TAO/tao/UIOP_Server_Request.cpp628
-rw-r--r--TAO/tao/UIOP_Server_Request.h203
11 files changed, 289 insertions, 1198 deletions
diff --git a/TAO/tao/Connect.cpp b/TAO/tao/Connect.cpp
index 42402d09636..aa379474670 100644
--- a/TAO/tao/Connect.cpp
+++ b/TAO/tao/Connect.cpp
@@ -5,7 +5,7 @@
#include "tao/IIOP_Transport.h"
#include "tao/debug.h"
#include "tao/GIOP.h"
-#include "tao/IIOP_Server_Request.h"
+#include "tao/GIOP_Server_Request.h"
#include "tao/ORB_Core.h"
#include "tao/POA.h"
#include "tao/CDR.h"
@@ -262,7 +262,7 @@ TAO_Server_Connection_Handler::handle_message (TAO_InputCDR &input,
{
// This will extract the request header, set <response_required> as
// appropriate.
- IIOP_ServerRequest request (input,
+ GIOP_ServerRequest request (input,
output,
this->orb_core_,
ACE_TRY_ENV);
@@ -407,7 +407,7 @@ TAO_Server_Connection_Handler::handle_locate (TAO_InputCDR &input,
// this->handle_locate_i (....);
- IIOP_ServerRequest serverRequest (locateRequestHeader.request_id,
+ GIOP_ServerRequest serverRequest (locateRequestHeader.request_id,
response_required,
tmp_key,
"_non_existent",
diff --git a/TAO/tao/UIOP_Server_Request.i b/TAO/tao/GIOP_Server_Request.i
index ee1d0226631..7cc1f15cdc0 100644
--- a/TAO/tao/UIOP_Server_Request.i
+++ b/TAO/tao/GIOP_Server_Request.i
@@ -5,20 +5,20 @@
// using reference counting wouldn't help much. Using a _clone()
// method would make the following methods really easy to implement,
// but that's hard to implement for the extremely optimized
-// UIOP_ServerRequest.
+// GIOP_ServerRequest.
// Another solution would be to modify the class hierarchy, make
// ServerRequest the "slow" version (with copies for each field) and
-// UIOP_ServerRequest the "fast" version (with no copies at all). The
+// GIOP_ServerRequest the "fast" version (with no copies at all). The
// first would be use for DII and the later for SII.
ACE_INLINE TAO_InputCDR &
-UIOP_ServerRequest::incoming (void)
+GIOP_ServerRequest::incoming (void)
{
return *this->incoming_;
}
ACE_INLINE TAO_OutputCDR &
-UIOP_ServerRequest::outgoing (void)
+GIOP_ServerRequest::outgoing (void)
{
return *this->outgoing_;
}
@@ -26,14 +26,14 @@ UIOP_ServerRequest::outgoing (void)
// Invocation attributes.
ACE_INLINE const char *
-UIOP_ServerRequest::operation (void) const
+GIOP_ServerRequest::operation (void) const
{
return this->operation_.c_str ();
}
// get the length of the operation name.
ACE_INLINE unsigned int
-UIOP_ServerRequest::operation_length (void) const
+GIOP_ServerRequest::operation_length (void) const
{
return this->operation_.length ();
}
@@ -41,38 +41,38 @@ UIOP_ServerRequest::operation_length (void) const
#if 0
//@@ (TAO) to do after Context is implemented
ACE_INLINE CORBA::Context_ptr
-UIOP_ServerRequest::ctx (void)
+GIOP_ServerRequest::ctx (void)
{
return 0;
}
#endif
ACE_INLINE CORBA::Boolean
-UIOP_ServerRequest::response_expected (void) const
+GIOP_ServerRequest::response_expected (void) const
{
return this->response_expected_;
}
ACE_INLINE CORBA::Principal_ptr
-UIOP_ServerRequest::principal (void) const
+GIOP_ServerRequest::principal (void) const
{
return this->requesting_principal_;
}
ACE_INLINE const TAO_ObjectKey &
-UIOP_ServerRequest::object_key (void) const
+GIOP_ServerRequest::object_key (void) const
{
return this->object_key_;
}
ACE_INLINE const TAO_GIOP_ServiceContextList &
-UIOP_ServerRequest::service_info (void) const
+GIOP_ServerRequest::service_info (void) const
{
return this->service_info_;
}
ACE_INLINE CORBA::ULong
-UIOP_ServerRequest::request_id (void)
+GIOP_ServerRequest::request_id (void)
{
return this->request_id_;
}
diff --git a/TAO/tao/IIOP_Server_Request.i b/TAO/tao/IIOP_Server_Request.i
deleted file mode 100644
index 78515a265c4..00000000000
--- a/TAO/tao/IIOP_Server_Request.i
+++ /dev/null
@@ -1,78 +0,0 @@
-// -*- C++ -*-
-// $Id$
-
-// @@ TODO TAO allocates its ServerRequest objects from the stack,
-// using reference counting wouldn't help much. Using a _clone()
-// method would make the following methods really easy to implement,
-// but that's hard to implement for the extremely optimized
-// IIOP_ServerRequest.
-// Another solution would be to modify the class hierarchy, make
-// ServerRequest the "slow" version (with copies for each field) and
-// IIOP_ServerRequest the "fast" version (with no copies at all). The
-// first would be use for DII and the later for SII.
-
-ACE_INLINE TAO_InputCDR &
-IIOP_ServerRequest::incoming (void)
-{
- return *this->incoming_;
-}
-
-ACE_INLINE TAO_OutputCDR &
-IIOP_ServerRequest::outgoing (void)
-{
- return *this->outgoing_;
-}
-
-// Invocation attributes.
-
-ACE_INLINE const char *
-IIOP_ServerRequest::operation (void) const
-{
- return this->operation_.c_str ();
-}
-
-// get the length of the operation name.
-ACE_INLINE unsigned int
-IIOP_ServerRequest::operation_length (void) const
-{
- return this->operation_.length ();
-}
-
-#if 0
-//@@ (TAO) to do after Context is implemented
-ACE_INLINE CORBA::Context_ptr
-IIOP_ServerRequest::ctx (void)
-{
- return 0;
-}
-#endif
-
-ACE_INLINE CORBA::Boolean
-IIOP_ServerRequest::response_expected (void) const
-{
- return this->response_expected_;
-}
-
-ACE_INLINE CORBA::Principal_ptr
-IIOP_ServerRequest::principal (void) const
-{
- return this->requesting_principal_;
-}
-
-ACE_INLINE const TAO_ObjectKey &
-IIOP_ServerRequest::object_key (void) const
-{
- return this->object_key_;
-}
-
-ACE_INLINE const TAO_GIOP_ServiceContextList &
-IIOP_ServerRequest::service_info (void) const
-{
- return this->service_info_;
-}
-
-ACE_INLINE CORBA::ULong
-IIOP_ServerRequest::request_id (void)
-{
- return this->request_id_;
-}
diff --git a/TAO/tao/Makefile b/TAO/tao/Makefile
index 5f16530f553..07960a9807d 100644
--- a/TAO/tao/Makefile
+++ b/TAO/tao/Makefile
@@ -45,8 +45,7 @@ PLUGGABLE_PROTOCOLS_FILES = \
IIOP_Profile \
IIOP_Transport \
IIOP_Connector \
- IIOP_Acceptor \
- IIOP_Server_Request
+ IIOP_Acceptor
DEFAULT_RESOURCES_FILES = \
default_client \
@@ -92,6 +91,7 @@ ORB_CORE_FILES = \
debug \
Object_KeyC \
GIOP \
+ GIOP_Server_Request \
Invocation \
ORB_Core \
params \
@@ -3038,224 +3038,6 @@ realclean:
$(TAO_ROOT)/tao/Sequence_T.i \
$(TAO_ROOT)/tao/Sequence_T.cpp \
$(TAO_ROOT)/tao/GIOP.i
-.obj/IIOP_Server_Request.o .obj/IIOP_Server_Request.so .shobj/IIOP_Server_Request.o .shobj/IIOP_Server_Request.so: IIOP_Server_Request.cpp \
- $(TAO_ROOT)/tao/IIOP_Server_Request.h \
- $(TAO_ROOT)/tao/Server_Request.h \
- $(TAO_ROOT)/tao/corbafwd.h \
- $(ACE_ROOT)/ace/CDR_Stream.h \
- $(ACE_ROOT)/ace/Message_Block.h \
- $(ACE_ROOT)/ace/ACE.h \
- $(ACE_ROOT)/ace/OS.h \
- $(ACE_ROOT)/ace/inc_user_config.h \
- $(ACE_ROOT)/ace/streams.h \
- $(ACE_ROOT)/ace/Basic_Types.h \
- $(ACE_ROOT)/ace/Basic_Types.i \
- $(ACE_ROOT)/ace/OS.i \
- $(ACE_ROOT)/ace/Trace.h \
- $(ACE_ROOT)/ace/Log_Msg.h \
- $(ACE_ROOT)/ace/Log_Record.h \
- $(ACE_ROOT)/ace/ACE.i \
- $(ACE_ROOT)/ace/Log_Priority.h \
- $(ACE_ROOT)/ace/SString.h \
- $(ACE_ROOT)/ace/SString.i \
- $(ACE_ROOT)/ace/Malloc_Base.h \
- $(ACE_ROOT)/ace/Log_Record.i \
- $(ACE_ROOT)/ace/Malloc.h \
- $(ACE_ROOT)/ace/Malloc.i \
- $(ACE_ROOT)/ace/Malloc_T.h \
- $(ACE_ROOT)/ace/Synch.h \
- $(ACE_ROOT)/ace/SV_Semaphore_Complex.h \
- $(ACE_ROOT)/ace/SV_Semaphore_Simple.h \
- $(ACE_ROOT)/ace/SV_Semaphore_Simple.i \
- $(ACE_ROOT)/ace/SV_Semaphore_Complex.i \
- $(ACE_ROOT)/ace/Synch.i \
- $(ACE_ROOT)/ace/Synch_T.h \
- $(ACE_ROOT)/ace/Event_Handler.h \
- $(ACE_ROOT)/ace/Event_Handler.i \
- $(ACE_ROOT)/ace/Synch_T.i \
- $(ACE_ROOT)/ace/Thread.h \
- $(ACE_ROOT)/ace/Thread.i \
- $(ACE_ROOT)/ace/Atomic_Op.i \
- $(ACE_ROOT)/ace/Synch_T.cpp \
- $(ACE_ROOT)/ace/Free_List.h \
- $(ACE_ROOT)/ace/Free_List.i \
- $(ACE_ROOT)/ace/Free_List.cpp \
- $(ACE_ROOT)/ace/Malloc_T.i \
- $(ACE_ROOT)/ace/Malloc_T.cpp \
- $(ACE_ROOT)/ace/Memory_Pool.h \
- $(ACE_ROOT)/ace/Signal.h \
- $(ACE_ROOT)/ace/Containers.h \
- $(ACE_ROOT)/ace/Containers.i \
- $(ACE_ROOT)/ace/Containers_T.h \
- $(ACE_ROOT)/ace/Containers_T.i \
- $(ACE_ROOT)/ace/Containers_T.cpp \
- $(ACE_ROOT)/ace/Signal.i \
- $(ACE_ROOT)/ace/Object_Manager.h \
- $(ACE_ROOT)/ace/Object_Manager.i \
- $(ACE_ROOT)/ace/Managed_Object.h \
- $(ACE_ROOT)/ace/Managed_Object.i \
- $(ACE_ROOT)/ace/Managed_Object.cpp \
- $(ACE_ROOT)/ace/Mem_Map.h \
- $(ACE_ROOT)/ace/Mem_Map.i \
- $(ACE_ROOT)/ace/Memory_Pool.i \
- $(ACE_ROOT)/ace/Message_Block.i \
- $(ACE_ROOT)/ace/Message_Block_T.h \
- $(ACE_ROOT)/ace/Message_Block_T.i \
- $(ACE_ROOT)/ace/Message_Block_T.cpp \
- $(ACE_ROOT)/ace/CDR_Stream.i \
- $(TAO_ROOT)/tao/try_macros.h \
- $(TAO_ROOT)/tao/orbconf.h \
- $(ACE_ROOT)/ace/CORBA_macros.h \
- $(TAO_ROOT)/tao/Object_KeyC.h \
- $(TAO_ROOT)/tao/Sequence.h \
- $(TAO_ROOT)/tao/Managed_Types.h \
- $(TAO_ROOT)/tao/ORB.h \
- $(TAO_ROOT)/tao/Exception.h \
- $(TAO_ROOT)/tao/Exception.i \
- $(TAO_ROOT)/tao/IOR_LookupTable.h \
- $(ACE_ROOT)/ace/Hash_Map_Manager.h \
- $(ACE_ROOT)/ace/Functor.h \
- $(ACE_ROOT)/ace/Functor.i \
- $(ACE_ROOT)/ace/Functor_T.h \
- $(ACE_ROOT)/ace/Functor_T.i \
- $(ACE_ROOT)/ace/Functor_T.cpp \
- $(ACE_ROOT)/ace/Hash_Map_Manager.i \
- $(ACE_ROOT)/ace/Hash_Map_Manager_T.h \
- $(ACE_ROOT)/ace/Hash_Map_Manager_T.i \
- $(ACE_ROOT)/ace/Hash_Map_Manager_T.cpp \
- $(ACE_ROOT)/ace/Service_Config.h \
- $(ACE_ROOT)/ace/Service_Object.h \
- $(ACE_ROOT)/ace/Shared_Object.h \
- $(ACE_ROOT)/ace/Shared_Object.i \
- $(ACE_ROOT)/ace/Service_Object.i \
- $(ACE_ROOT)/ace/Service_Config.i \
- $(ACE_ROOT)/ace/Reactor.h \
- $(ACE_ROOT)/ace/Handle_Set.h \
- $(ACE_ROOT)/ace/Handle_Set.i \
- $(ACE_ROOT)/ace/Timer_Queue.h \
- $(ACE_ROOT)/ace/Timer_Queue_T.h \
- $(ACE_ROOT)/ace/Timer_Queue_T.i \
- $(ACE_ROOT)/ace/Timer_Queue_T.cpp \
- $(ACE_ROOT)/ace/Reactor.i \
- $(ACE_ROOT)/ace/Reactor_Impl.h \
- $(ACE_ROOT)/ace/Svc_Conf_Tokens.h \
- $(TAO_ROOT)/tao/ORB.i \
- $(TAO_ROOT)/tao/Managed_Types.i \
- $(TAO_ROOT)/tao/Sequence.i \
- $(TAO_ROOT)/tao/Object_KeyC.i \
- $(TAO_ROOT)/tao/GIOP.h \
- $(TAO_ROOT)/tao/Sequence_T.h \
- $(TAO_ROOT)/tao/Sequence_T.i \
- $(TAO_ROOT)/tao/Sequence_T.cpp \
- $(TAO_ROOT)/tao/GIOP.i \
- $(TAO_ROOT)/tao/Object.h \
- $(TAO_ROOT)/tao/Object.i \
- $(TAO_ROOT)/tao/Server_Request.i \
- $(TAO_ROOT)/tao/IIOP_Server_Request.i \
- $(TAO_ROOT)/tao/CDR.h \
- $(TAO_ROOT)/tao/Typecode.h \
- $(TAO_ROOT)/tao/Typecode.i \
- $(TAO_ROOT)/tao/CDR.i \
- $(TAO_ROOT)/tao/POAC.h \
- $(TAO_ROOT)/tao/PolicyC.h \
- $(TAO_ROOT)/tao/CurrentC.h \
- $(TAO_ROOT)/tao/CurrentC.i \
- $(TAO_ROOT)/tao/PolicyC.i \
- $(TAO_ROOT)/tao/Environment.h \
- $(TAO_ROOT)/tao/Environment.i \
- $(TAO_ROOT)/tao/POAC.i \
- $(TAO_ROOT)/tao/NVList.h \
- $(TAO_ROOT)/tao/Any.h \
- $(TAO_ROOT)/tao/Any.i \
- $(TAO_ROOT)/tao/NVList.i \
- $(TAO_ROOT)/tao/Principal.h \
- $(TAO_ROOT)/tao/Principal.i \
- $(TAO_ROOT)/tao/ORB_Core.h \
- $(ACE_ROOT)/ace/Singleton.h \
- $(ACE_ROOT)/ace/Singleton.i \
- $(ACE_ROOT)/ace/Singleton.cpp \
- $(TAO_ROOT)/tao/Policy_Manager.h \
- $(TAO_ROOT)/tao/POA_CORBA.h \
- $(TAO_ROOT)/tao/DynAnyC.h \
- $(TAO_ROOT)/tao/DynAnyC.i \
- $(TAO_ROOT)/tao/Servant_Base.h \
- $(TAO_ROOT)/tao/Servant_Base.i \
- $(TAO_ROOT)/tao/Policy_Manager.i \
- $(TAO_ROOT)/tao/Resource_Factory.h \
- $(TAO_ROOT)/tao/IIOP_Connector.h \
- $(ACE_ROOT)/ace/Connector.h \
- $(ACE_ROOT)/ace/Map_Manager.h \
- $(ACE_ROOT)/ace/Map_Manager.i \
- $(ACE_ROOT)/ace/Map_Manager.cpp \
- $(ACE_ROOT)/ace/Svc_Handler.h \
- $(ACE_ROOT)/ace/Synch_Options.h \
- $(ACE_ROOT)/ace/Synch_Options.i \
- $(ACE_ROOT)/ace/Task.h \
- $(ACE_ROOT)/ace/Thread_Manager.h \
- $(ACE_ROOT)/ace/Thread_Manager.i \
- $(ACE_ROOT)/ace/Task.i \
- $(ACE_ROOT)/ace/Task_T.h \
- $(ACE_ROOT)/ace/Message_Queue.h \
- $(ACE_ROOT)/ace/IO_Cntl_Msg.h \
- $(ACE_ROOT)/ace/Message_Queue_T.h \
- $(ACE_ROOT)/ace/Message_Queue_T.i \
- $(ACE_ROOT)/ace/Message_Queue_T.cpp \
- $(ACE_ROOT)/ace/Strategies.h \
- $(ACE_ROOT)/ace/Strategies_T.h \
- $(ACE_ROOT)/ace/Strategies_T.i \
- $(ACE_ROOT)/ace/Strategies_T.cpp \
- $(ACE_ROOT)/ace/Service_Repository.h \
- $(ACE_ROOT)/ace/Service_Types.h \
- $(ACE_ROOT)/ace/Service_Types.i \
- $(ACE_ROOT)/ace/Service_Repository.i \
- $(ACE_ROOT)/ace/WFMO_Reactor.h \
- $(ACE_ROOT)/ace/WFMO_Reactor.i \
- $(ACE_ROOT)/ace/Strategies.i \
- $(ACE_ROOT)/ace/Message_Queue.i \
- $(ACE_ROOT)/ace/Task_T.i \
- $(ACE_ROOT)/ace/Task_T.cpp \
- $(ACE_ROOT)/ace/Module.h \
- $(ACE_ROOT)/ace/Module.i \
- $(ACE_ROOT)/ace/Module.cpp \
- $(ACE_ROOT)/ace/Stream_Modules.h \
- $(ACE_ROOT)/ace/Stream_Modules.i \
- $(ACE_ROOT)/ace/Stream_Modules.cpp \
- $(ACE_ROOT)/ace/Svc_Handler.i \
- $(ACE_ROOT)/ace/Svc_Handler.cpp \
- $(ACE_ROOT)/ace/Dynamic.h \
- $(ACE_ROOT)/ace/Dynamic.i \
- $(ACE_ROOT)/ace/Connector.i \
- $(ACE_ROOT)/ace/Connector.cpp \
- $(ACE_ROOT)/ace/SOCK_Connector.h \
- $(ACE_ROOT)/ace/SOCK_Stream.h \
- $(ACE_ROOT)/ace/SOCK_IO.h \
- $(ACE_ROOT)/ace/SOCK.h \
- $(ACE_ROOT)/ace/Addr.h \
- $(ACE_ROOT)/ace/Addr.i \
- $(ACE_ROOT)/ace/IPC_SAP.h \
- $(ACE_ROOT)/ace/IPC_SAP.i \
- $(ACE_ROOT)/ace/SOCK.i \
- $(ACE_ROOT)/ace/SOCK_IO.i \
- $(ACE_ROOT)/ace/INET_Addr.h \
- $(ACE_ROOT)/ace/INET_Addr.i \
- $(ACE_ROOT)/ace/SOCK_Stream.i \
- $(ACE_ROOT)/ace/Time_Value.h \
- $(ACE_ROOT)/ace/SOCK_Connector.i \
- $(TAO_ROOT)/tao/Pluggable.h \
- $(TAO_ROOT)/tao/Connect.h \
- $(ACE_ROOT)/ace/Acceptor.h \
- $(ACE_ROOT)/ace/Acceptor.i \
- $(ACE_ROOT)/ace/Acceptor.cpp \
- $(ACE_ROOT)/ace/SOCK_Acceptor.h \
- $(ACE_ROOT)/ace/SOCK_Acceptor.i \
- $(TAO_ROOT)/tao/Connect.i \
- $(TAO_ROOT)/tao/params.h \
- $(TAO_ROOT)/tao/params.i \
- $(TAO_ROOT)/tao/ORB_Core.i \
- $(ACE_ROOT)/ace/Dynamic_Service.h \
- $(ACE_ROOT)/ace/Dynamic_Service.cpp \
- $(TAO_ROOT)/tao/Timeprobe.h \
- $(ACE_ROOT)/ace/Timeprobe.h
.obj/default_client.o .obj/default_client.so .shobj/default_client.o .shobj/default_client.so: default_client.cpp \
$(TAO_ROOT)/tao/default_client.h \
$(TAO_ROOT)/tao/Client_Strategy_Factory.h \
@@ -8263,14 +8045,14 @@ realclean:
$(TAO_ROOT)/tao/Sequence_T.i \
$(TAO_ROOT)/tao/Sequence_T.cpp \
$(TAO_ROOT)/tao/GIOP.i \
- $(TAO_ROOT)/tao/IIOP_Server_Request.h \
+ $(TAO_ROOT)/tao/GIOP_Server_Request.h \
$(TAO_ROOT)/tao/Server_Request.h \
$(TAO_ROOT)/tao/Object_KeyC.h \
$(TAO_ROOT)/tao/Object_KeyC.i \
$(TAO_ROOT)/tao/Object.h \
$(TAO_ROOT)/tao/Object.i \
$(TAO_ROOT)/tao/Server_Request.i \
- $(TAO_ROOT)/tao/IIOP_Server_Request.i \
+ $(TAO_ROOT)/tao/GIOP_Server_Request.i \
$(TAO_ROOT)/tao/ORB_Core.h \
$(TAO_ROOT)/tao/Environment.h \
$(TAO_ROOT)/tao/Environment.i \
@@ -8716,6 +8498,224 @@ realclean:
$(TAO_ROOT)/tao/ORB_Core.i \
$(ACE_ROOT)/ace/Dynamic_Service.h \
$(ACE_ROOT)/ace/Dynamic_Service.cpp
+.obj/GIOP_Server_Request.o .obj/GIOP_Server_Request.so .shobj/GIOP_Server_Request.o .shobj/GIOP_Server_Request.so: GIOP_Server_Request.cpp \
+ $(TAO_ROOT)/tao/GIOP_Server_Request.h \
+ $(TAO_ROOT)/tao/Server_Request.h \
+ $(TAO_ROOT)/tao/corbafwd.h \
+ $(ACE_ROOT)/ace/CDR_Stream.h \
+ $(ACE_ROOT)/ace/Message_Block.h \
+ $(ACE_ROOT)/ace/ACE.h \
+ $(ACE_ROOT)/ace/OS.h \
+ $(ACE_ROOT)/ace/inc_user_config.h \
+ $(ACE_ROOT)/ace/streams.h \
+ $(ACE_ROOT)/ace/Basic_Types.h \
+ $(ACE_ROOT)/ace/Basic_Types.i \
+ $(ACE_ROOT)/ace/OS.i \
+ $(ACE_ROOT)/ace/Trace.h \
+ $(ACE_ROOT)/ace/Log_Msg.h \
+ $(ACE_ROOT)/ace/Log_Record.h \
+ $(ACE_ROOT)/ace/ACE.i \
+ $(ACE_ROOT)/ace/Log_Priority.h \
+ $(ACE_ROOT)/ace/SString.h \
+ $(ACE_ROOT)/ace/SString.i \
+ $(ACE_ROOT)/ace/Malloc_Base.h \
+ $(ACE_ROOT)/ace/Log_Record.i \
+ $(ACE_ROOT)/ace/Malloc.h \
+ $(ACE_ROOT)/ace/Malloc.i \
+ $(ACE_ROOT)/ace/Malloc_T.h \
+ $(ACE_ROOT)/ace/Synch.h \
+ $(ACE_ROOT)/ace/SV_Semaphore_Complex.h \
+ $(ACE_ROOT)/ace/SV_Semaphore_Simple.h \
+ $(ACE_ROOT)/ace/SV_Semaphore_Simple.i \
+ $(ACE_ROOT)/ace/SV_Semaphore_Complex.i \
+ $(ACE_ROOT)/ace/Synch.i \
+ $(ACE_ROOT)/ace/Synch_T.h \
+ $(ACE_ROOT)/ace/Event_Handler.h \
+ $(ACE_ROOT)/ace/Event_Handler.i \
+ $(ACE_ROOT)/ace/Synch_T.i \
+ $(ACE_ROOT)/ace/Thread.h \
+ $(ACE_ROOT)/ace/Thread.i \
+ $(ACE_ROOT)/ace/Atomic_Op.i \
+ $(ACE_ROOT)/ace/Synch_T.cpp \
+ $(ACE_ROOT)/ace/Free_List.h \
+ $(ACE_ROOT)/ace/Free_List.i \
+ $(ACE_ROOT)/ace/Free_List.cpp \
+ $(ACE_ROOT)/ace/Malloc_T.i \
+ $(ACE_ROOT)/ace/Malloc_T.cpp \
+ $(ACE_ROOT)/ace/Memory_Pool.h \
+ $(ACE_ROOT)/ace/Signal.h \
+ $(ACE_ROOT)/ace/Containers.h \
+ $(ACE_ROOT)/ace/Containers.i \
+ $(ACE_ROOT)/ace/Containers_T.h \
+ $(ACE_ROOT)/ace/Containers_T.i \
+ $(ACE_ROOT)/ace/Containers_T.cpp \
+ $(ACE_ROOT)/ace/Signal.i \
+ $(ACE_ROOT)/ace/Object_Manager.h \
+ $(ACE_ROOT)/ace/Object_Manager.i \
+ $(ACE_ROOT)/ace/Managed_Object.h \
+ $(ACE_ROOT)/ace/Managed_Object.i \
+ $(ACE_ROOT)/ace/Managed_Object.cpp \
+ $(ACE_ROOT)/ace/Mem_Map.h \
+ $(ACE_ROOT)/ace/Mem_Map.i \
+ $(ACE_ROOT)/ace/Memory_Pool.i \
+ $(ACE_ROOT)/ace/Message_Block.i \
+ $(ACE_ROOT)/ace/Message_Block_T.h \
+ $(ACE_ROOT)/ace/Message_Block_T.i \
+ $(ACE_ROOT)/ace/Message_Block_T.cpp \
+ $(ACE_ROOT)/ace/CDR_Stream.i \
+ $(TAO_ROOT)/tao/try_macros.h \
+ $(TAO_ROOT)/tao/orbconf.h \
+ $(ACE_ROOT)/ace/CORBA_macros.h \
+ $(TAO_ROOT)/tao/Object_KeyC.h \
+ $(TAO_ROOT)/tao/Sequence.h \
+ $(TAO_ROOT)/tao/Managed_Types.h \
+ $(TAO_ROOT)/tao/ORB.h \
+ $(TAO_ROOT)/tao/Exception.h \
+ $(TAO_ROOT)/tao/Exception.i \
+ $(TAO_ROOT)/tao/IOR_LookupTable.h \
+ $(ACE_ROOT)/ace/Hash_Map_Manager.h \
+ $(ACE_ROOT)/ace/Functor.h \
+ $(ACE_ROOT)/ace/Functor.i \
+ $(ACE_ROOT)/ace/Functor_T.h \
+ $(ACE_ROOT)/ace/Functor_T.i \
+ $(ACE_ROOT)/ace/Functor_T.cpp \
+ $(ACE_ROOT)/ace/Hash_Map_Manager.i \
+ $(ACE_ROOT)/ace/Hash_Map_Manager_T.h \
+ $(ACE_ROOT)/ace/Hash_Map_Manager_T.i \
+ $(ACE_ROOT)/ace/Hash_Map_Manager_T.cpp \
+ $(ACE_ROOT)/ace/Service_Config.h \
+ $(ACE_ROOT)/ace/Service_Object.h \
+ $(ACE_ROOT)/ace/Shared_Object.h \
+ $(ACE_ROOT)/ace/Shared_Object.i \
+ $(ACE_ROOT)/ace/Service_Object.i \
+ $(ACE_ROOT)/ace/Service_Config.i \
+ $(ACE_ROOT)/ace/Reactor.h \
+ $(ACE_ROOT)/ace/Handle_Set.h \
+ $(ACE_ROOT)/ace/Handle_Set.i \
+ $(ACE_ROOT)/ace/Timer_Queue.h \
+ $(ACE_ROOT)/ace/Timer_Queue_T.h \
+ $(ACE_ROOT)/ace/Timer_Queue_T.i \
+ $(ACE_ROOT)/ace/Timer_Queue_T.cpp \
+ $(ACE_ROOT)/ace/Reactor.i \
+ $(ACE_ROOT)/ace/Reactor_Impl.h \
+ $(ACE_ROOT)/ace/Svc_Conf_Tokens.h \
+ $(TAO_ROOT)/tao/ORB.i \
+ $(TAO_ROOT)/tao/Managed_Types.i \
+ $(TAO_ROOT)/tao/Sequence.i \
+ $(TAO_ROOT)/tao/Object_KeyC.i \
+ $(TAO_ROOT)/tao/GIOP.h \
+ $(TAO_ROOT)/tao/Sequence_T.h \
+ $(TAO_ROOT)/tao/Sequence_T.i \
+ $(TAO_ROOT)/tao/Sequence_T.cpp \
+ $(TAO_ROOT)/tao/GIOP.i \
+ $(TAO_ROOT)/tao/Object.h \
+ $(TAO_ROOT)/tao/Object.i \
+ $(TAO_ROOT)/tao/Server_Request.i \
+ $(TAO_ROOT)/tao/GIOP_Server_Request.i \
+ $(TAO_ROOT)/tao/CDR.h \
+ $(TAO_ROOT)/tao/Typecode.h \
+ $(TAO_ROOT)/tao/Typecode.i \
+ $(TAO_ROOT)/tao/CDR.i \
+ $(TAO_ROOT)/tao/POAC.h \
+ $(TAO_ROOT)/tao/PolicyC.h \
+ $(TAO_ROOT)/tao/CurrentC.h \
+ $(TAO_ROOT)/tao/CurrentC.i \
+ $(TAO_ROOT)/tao/PolicyC.i \
+ $(TAO_ROOT)/tao/Environment.h \
+ $(TAO_ROOT)/tao/Environment.i \
+ $(TAO_ROOT)/tao/POAC.i \
+ $(TAO_ROOT)/tao/NVList.h \
+ $(TAO_ROOT)/tao/Any.h \
+ $(TAO_ROOT)/tao/Any.i \
+ $(TAO_ROOT)/tao/NVList.i \
+ $(TAO_ROOT)/tao/Principal.h \
+ $(TAO_ROOT)/tao/Principal.i \
+ $(TAO_ROOT)/tao/ORB_Core.h \
+ $(ACE_ROOT)/ace/Singleton.h \
+ $(ACE_ROOT)/ace/Singleton.i \
+ $(ACE_ROOT)/ace/Singleton.cpp \
+ $(TAO_ROOT)/tao/Policy_Manager.h \
+ $(TAO_ROOT)/tao/POA_CORBA.h \
+ $(TAO_ROOT)/tao/DynAnyC.h \
+ $(TAO_ROOT)/tao/DynAnyC.i \
+ $(TAO_ROOT)/tao/Servant_Base.h \
+ $(TAO_ROOT)/tao/Servant_Base.i \
+ $(TAO_ROOT)/tao/Policy_Manager.i \
+ $(TAO_ROOT)/tao/Resource_Factory.h \
+ $(TAO_ROOT)/tao/IIOP_Connector.h \
+ $(ACE_ROOT)/ace/Connector.h \
+ $(ACE_ROOT)/ace/Map_Manager.h \
+ $(ACE_ROOT)/ace/Map_Manager.i \
+ $(ACE_ROOT)/ace/Map_Manager.cpp \
+ $(ACE_ROOT)/ace/Svc_Handler.h \
+ $(ACE_ROOT)/ace/Synch_Options.h \
+ $(ACE_ROOT)/ace/Synch_Options.i \
+ $(ACE_ROOT)/ace/Task.h \
+ $(ACE_ROOT)/ace/Thread_Manager.h \
+ $(ACE_ROOT)/ace/Thread_Manager.i \
+ $(ACE_ROOT)/ace/Task.i \
+ $(ACE_ROOT)/ace/Task_T.h \
+ $(ACE_ROOT)/ace/Message_Queue.h \
+ $(ACE_ROOT)/ace/IO_Cntl_Msg.h \
+ $(ACE_ROOT)/ace/Message_Queue_T.h \
+ $(ACE_ROOT)/ace/Message_Queue_T.i \
+ $(ACE_ROOT)/ace/Message_Queue_T.cpp \
+ $(ACE_ROOT)/ace/Strategies.h \
+ $(ACE_ROOT)/ace/Strategies_T.h \
+ $(ACE_ROOT)/ace/Strategies_T.i \
+ $(ACE_ROOT)/ace/Strategies_T.cpp \
+ $(ACE_ROOT)/ace/Service_Repository.h \
+ $(ACE_ROOT)/ace/Service_Types.h \
+ $(ACE_ROOT)/ace/Service_Types.i \
+ $(ACE_ROOT)/ace/Service_Repository.i \
+ $(ACE_ROOT)/ace/WFMO_Reactor.h \
+ $(ACE_ROOT)/ace/WFMO_Reactor.i \
+ $(ACE_ROOT)/ace/Strategies.i \
+ $(ACE_ROOT)/ace/Message_Queue.i \
+ $(ACE_ROOT)/ace/Task_T.i \
+ $(ACE_ROOT)/ace/Task_T.cpp \
+ $(ACE_ROOT)/ace/Module.h \
+ $(ACE_ROOT)/ace/Module.i \
+ $(ACE_ROOT)/ace/Module.cpp \
+ $(ACE_ROOT)/ace/Stream_Modules.h \
+ $(ACE_ROOT)/ace/Stream_Modules.i \
+ $(ACE_ROOT)/ace/Stream_Modules.cpp \
+ $(ACE_ROOT)/ace/Svc_Handler.i \
+ $(ACE_ROOT)/ace/Svc_Handler.cpp \
+ $(ACE_ROOT)/ace/Dynamic.h \
+ $(ACE_ROOT)/ace/Dynamic.i \
+ $(ACE_ROOT)/ace/Connector.i \
+ $(ACE_ROOT)/ace/Connector.cpp \
+ $(ACE_ROOT)/ace/SOCK_Connector.h \
+ $(ACE_ROOT)/ace/SOCK_Stream.h \
+ $(ACE_ROOT)/ace/SOCK_IO.h \
+ $(ACE_ROOT)/ace/SOCK.h \
+ $(ACE_ROOT)/ace/Addr.h \
+ $(ACE_ROOT)/ace/Addr.i \
+ $(ACE_ROOT)/ace/IPC_SAP.h \
+ $(ACE_ROOT)/ace/IPC_SAP.i \
+ $(ACE_ROOT)/ace/SOCK.i \
+ $(ACE_ROOT)/ace/SOCK_IO.i \
+ $(ACE_ROOT)/ace/INET_Addr.h \
+ $(ACE_ROOT)/ace/INET_Addr.i \
+ $(ACE_ROOT)/ace/SOCK_Stream.i \
+ $(ACE_ROOT)/ace/Time_Value.h \
+ $(ACE_ROOT)/ace/SOCK_Connector.i \
+ $(TAO_ROOT)/tao/Pluggable.h \
+ $(TAO_ROOT)/tao/Connect.h \
+ $(ACE_ROOT)/ace/Acceptor.h \
+ $(ACE_ROOT)/ace/Acceptor.i \
+ $(ACE_ROOT)/ace/Acceptor.cpp \
+ $(ACE_ROOT)/ace/SOCK_Acceptor.h \
+ $(ACE_ROOT)/ace/SOCK_Acceptor.i \
+ $(TAO_ROOT)/tao/Connect.i \
+ $(TAO_ROOT)/tao/params.h \
+ $(TAO_ROOT)/tao/params.i \
+ $(TAO_ROOT)/tao/ORB_Core.i \
+ $(ACE_ROOT)/ace/Dynamic_Service.h \
+ $(ACE_ROOT)/ace/Dynamic_Service.cpp \
+ $(TAO_ROOT)/tao/Timeprobe.h \
+ $(ACE_ROOT)/ace/Timeprobe.h
.obj/Invocation.o .obj/Invocation.so .shobj/Invocation.o .shobj/Invocation.so: Invocation.cpp \
$(TAO_ROOT)/tao/Invocation.h \
$(TAO_ROOT)/tao/CDR.h \
diff --git a/TAO/tao/TAO.dsp b/TAO/tao/TAO.dsp
index c076feb160c..5b4d6f4aab4 100644
--- a/TAO/tao/TAO.dsp
+++ b/TAO/tao/TAO.dsp
@@ -14756,7 +14756,7 @@ SOURCE=.\IIOP_Profile.cpp
# End Source File
# Begin Source File
-SOURCE=.\IIOP_Server_Request.cpp
+SOURCE=.\GIOP_Server_Request.cpp
!IF "$(CFG)" == "TAO - Win32 Release"
@@ -30743,7 +30743,7 @@ SOURCE=.\IIOP_Profile.h
# End Source File
# Begin Source File
-SOURCE=.\IIOP_Server_Request.h
+SOURCE=.\GIOP_Server_Request.h
# End Source File
# Begin Source File
@@ -30979,7 +30979,7 @@ SOURCE=.\IIOP_ORB.i
# End Source File
# Begin Source File
-SOURCE=.\IIOP_Server_Request.i
+SOURCE=.\GIOP_Server_Request.i
# End Source File
# Begin Source File
diff --git a/TAO/tao/TAO_Static.dsp b/TAO/tao/TAO_Static.dsp
index 6be526be3b9..e740f4af77f 100644
--- a/TAO/tao/TAO_Static.dsp
+++ b/TAO/tao/TAO_Static.dsp
@@ -211,7 +211,7 @@ SOURCE=.\IIOP_Profile.cpp
# End Source File
# Begin Source File
-SOURCE=.\IIOP_Server_Request.cpp
+SOURCE=.\GIOP_Server_Request.cpp
# End Source File
# Begin Source File
@@ -487,7 +487,7 @@ SOURCE=.\IIOP_Profile.h
# End Source File
# Begin Source File
-SOURCE=.\IIOP_Server_Request.h
+SOURCE=.\GIOP_Server_Request.h
# End Source File
# Begin Source File
@@ -719,7 +719,7 @@ SOURCE=.\IIOP_ORB.i
# End Source File
# Begin Source File
-SOURCE=.\IIOP_Server_Request.i
+SOURCE=.\GIOP_Server_Request.i
# End Source File
# Begin Source File
diff --git a/TAO/tao/UIOP_Connect.cpp b/TAO/tao/UIOP_Connect.cpp
index 8e46a3910a1..fceff511557 100644
--- a/TAO/tao/UIOP_Connect.cpp
+++ b/TAO/tao/UIOP_Connect.cpp
@@ -4,7 +4,7 @@
#include "tao/debug.h"
#include "tao/GIOP.h"
-#include "tao/UIOP_Server_Request.h"
+#include "tao/GIOP_Server_Request.h"
#include "tao/ORB_Core.h"
#include "tao/POA.h"
#include "tao/CDR.h"
@@ -212,7 +212,7 @@ TAO_UIOP_Server_Connection_Handler::handle_message (TAO_InputCDR &input,
{
// This will extract the request header, set <response_required> as
// appropriate.
- UIOP_ServerRequest request (input,
+ GIOP_ServerRequest request (input,
output,
this->orb_core_,
ACE_TRY_ENV);
@@ -357,7 +357,7 @@ TAO_UIOP_Server_Connection_Handler::handle_locate (TAO_InputCDR &input,
// this->handle_locate_i (....);
- UIOP_ServerRequest serverRequest (locateRequestHeader.request_id,
+ GIOP_ServerRequest serverRequest (locateRequestHeader.request_id,
response_required,
tmp_key,
"_non_existent",
diff --git a/TAO/tao/UIOP_Server_Request.cpp b/TAO/tao/UIOP_Server_Request.cpp
deleted file mode 100644
index ad51b99474b..00000000000
--- a/TAO/tao/UIOP_Server_Request.cpp
+++ /dev/null
@@ -1,628 +0,0 @@
-// $Id$
-
-// Implementation of the Dynamic Server Skeleton Interface (for UIOP)
-
-#include "tao/UIOP_Server_Request.h"
-
-#include "tao/CDR.h"
-#include "tao/POAC.h"
-#include "tao/Environment.h"
-#include "tao/NVList.h"
-#include "tao/Principal.h"
-#include "tao/ORB_Core.h"
-#include "tao/Timeprobe.h"
-#include "tao/Any.h"
-
-#if !defined (__ACE_INLINE__)
-# include "tao/UIOP_Server_Request.i"
-#endif /* ! __ACE_INLINE__ */
-
-ACE_RCSID(tao, UIOP_Server_Request, "$Id$")
-
-#if defined (ACE_ENABLE_TIMEPROBES)
-
-static const char *TAO_Server_Request_Timeprobe_Description[] =
- {
- "Server_Request::Server_Request - start",
- "Server_Request::Server_Request - end",
- };
-
-enum
- {
- // Timeprobe description table start key
- TAO_SERVER_REQUEST_START = 400,
- TAO_SERVER_REQUEST_END
- };
-
-// Setup Timeprobes
-ACE_TIMEPROBE_EVENT_DESCRIPTIONS (TAO_Server_Request_Timeprobe_Description,
- TAO_SERVER_REQUEST_START);
-
-#endif /* ACE_ENABLE_TIMEPROBES */
-
-UIOP_ServerRequest::UIOP_ServerRequest (TAO_InputCDR &input,
- TAO_OutputCDR &output,
- TAO_ORB_Core *orb_core,
- CORBA::Environment &env)
- : incoming_ (&input),
- outgoing_ (&output),
- response_expected_ (0),
-
-#if !defined (TAO_HAS_MINIMUM_CORBA)
-
- params_ (0),
-
-#endif /* TAO_HAS_MINIMUM_CORBA */
-
- retval_ (0),
- exception_ (0),
- exception_type_ (TAO_GIOP_NO_EXCEPTION),
- orb_core_ (orb_core),
- service_info_ (),
- request_id_ (0),
- object_key_ (),
- requesting_principal_ (0)
-{
- ACE_FUNCTION_TIMEPROBE (TAO_SERVER_REQUEST_START);
-
- this->parse_header (env);
-}
-
-void
-UIOP_ServerRequest::parse_header_std (CORBA::Environment &ACE_TRY_ENV)
-{
- // Tear out the service context ... we currently ignore it, but it
- // should probably be passed to each ORB service as appropriate
- // (e.g. transactions, security).
- //
- // NOTE: As security support kicks in, this is a good place to
- // verify a digital signature, if that is required in this security
- // environment. It may be required even when using IPSEC security
- // infrastructure.
-
- TAO_InputCDR& input = *this->incoming_;
-
- input >> this->service_info_;
- CORBA::Boolean hdr_status = input.good_bit ();
-
- // Get the rest of the request header ...
-
- hdr_status = hdr_status && input.read_ulong (this->request_id_);
- hdr_status = hdr_status && input.read_boolean (this->response_expected_);
-
- // We use ad-hoc demarshalling here: there is no need to increase
- // the reference count on the CDR message block, because this key
- // will not outlive the request (or the message block).
-
- CORBA::Long key_length;
- hdr_status = hdr_status && input.read_long (key_length);
- if (hdr_status)
- {
- this->object_key_.replace (key_length, key_length,
- (CORBA::Octet*)input.rd_ptr (),
- 0);
- input.skip_bytes (key_length);
- }
-
- CORBA::Long length;
- hdr_status = hdr_status && input.read_long (length);
- if (hdr_status)
- {
- // Do not include NULL character at the end.
- this->operation_.set (input.rd_ptr (),
- length - 1,
- 0);
- hdr_status = input.skip_bytes (length);
- }
-
- if (hdr_status)
- {
- input >> this->requesting_principal_;
- hdr_status = input.good_bit ();
- }
-
- if (!hdr_status)
- ACE_THROW (CORBA::COMM_FAILURE ());
-
-}
-
-void
-UIOP_ServerRequest::parse_header_lite (CORBA::Environment &ACE_TRY_ENV)
-{
- TAO_InputCDR& input = *this->incoming_;
-
- CORBA::Boolean hdr_status = input.good_bit ();
-
- // Get the rest of the request header ...
-
- hdr_status = hdr_status && input.read_ulong (this->request_id_);
- hdr_status = hdr_status && input.read_boolean (this->response_expected_);
-
- // We use ad-hoc demarshalling here: there is no need to increase
- // the reference count on the CDR message block, because this key
- // will not outlive the request (or the message block).
-
- CORBA::Long key_length;
- hdr_status = hdr_status && input.read_long (key_length);
- if (hdr_status)
- {
- this->object_key_.replace (key_length, key_length,
- (CORBA::Octet*)input.rd_ptr (),
- 0);
- input.skip_bytes (key_length);
- }
-
- CORBA::Long length;
- hdr_status = hdr_status && input.read_long (length);
- if (hdr_status)
- {
- // Do not include NULL character at the end.
- this->operation_.set (input.rd_ptr (),
- length - 1,
- 0);
- hdr_status = input.skip_bytes (length);
- }
-
- if (!hdr_status)
- ACE_THROW (CORBA::COMM_FAILURE ());
-}
-
-
-
-void
-UIOP_ServerRequest::parse_header (CORBA::Environment &env)
-{
- if (this->orb_core_->orb_params ()->use_lite_protocol ())
- this->parse_header_lite (env);
- else
- this->parse_header_std (env);
-}
-
-// This constructor is used, by the locate request code
-
-UIOP_ServerRequest::UIOP_ServerRequest (CORBA::ULong &request_id,
- CORBA::Boolean &response_expected,
- TAO_ObjectKey &object_key,
- const ACE_CString &operation,
- TAO_OutputCDR &output,
- TAO_ORB_Core *orb_core,
- CORBA::Environment &)
- : operation_ (operation),
- incoming_ (0),
- outgoing_ (&output),
- response_expected_ (response_expected),
-
-#if !defined (TAO_HAS_MINIMUM_CORBA)
-
- params_ (0),
-
-#endif /* TAO_HAS_MINIMUM_CORBA */
-
- retval_ (0),
- exception_ (0),
- exception_type_ (TAO_GIOP_NO_EXCEPTION),
- orb_core_ (orb_core),
- service_info_ (0),
- request_id_ (request_id),
- object_key_ (object_key),
- requesting_principal_ (0)
-{
-}
-
-UIOP_ServerRequest::~UIOP_ServerRequest (void)
-{
-
-#if !defined (TAO_HAS_MINIMUM_CORBA)
-
- if (this->params_)
- CORBA::release (this->params_);
-
-#endif /* TAO_HAS_MINIMUM_CORBA */
-
- delete this->retval_;
- delete this->exception_;
-}
-
-CORBA::ORB_ptr
-UIOP_ServerRequest::orb (void)
-{
- return this->orb_core_->orb ();
-}
-
-TAO_POA *
-UIOP_ServerRequest::oa (void)
-{
- return this->orb_core_->root_poa ();
-}
-
-#if !defined (TAO_HAS_MINIMUM_CORBA)
-
-// Unmarshal in/inout params, and set up to marshal the appropriate
-// inout/out/return values later on.
-
-void
-UIOP_ServerRequest::arguments (CORBA::NVList_ptr &list,
- CORBA::Environment &env)
-{
- env.clear ();
-
- // Save params for later use when marshaling the reply.
- this->params_ = list;
-
- // Then unmarshal each "in" and "inout" parameter.
- for (u_int i = 0; i < list->count (); i++)
- {
- CORBA::NamedValue_ptr nv = list->item (i, env);
-
- // check if it is an in or inout parameter
- if (ACE_BIT_DISABLED (nv->flags (), CORBA::ARG_IN | CORBA::ARG_INOUT))
- continue;
-
- CORBA::Any_ptr any = nv->value ();
- CORBA::TypeCode_var tc = any->type ();
-
- // @@ (JP) The following code depends on the fact that
- // TO_InputCDR does not contain chained message blocks.
- char *begin, *end;
-
- // This will be the start of a new message block.
- begin = this->incoming_->rd_ptr ();
-
- // Skip over the next aregument.
- CORBA::TypeCode::traverse_status status =
- this->incoming_->skip (tc.in (), env);
-
- if (status != CORBA::TypeCode::TRAVERSE_CONTINUE)
- {
- const char* param_name = nv->name ();
-
- if (param_name == 0)
- param_name = "(no name given)";
-
- ACE_ERROR ((LM_ERROR,
- "UIOP_ServerRequest::arguments - problem while"
- " decoding parameter %d <%s>\n", i, param_name));
- return;
- }
-
- // This will be the end of the new message block.
- end = this->incoming_->rd_ptr ();
-
- // Allocate the new message block and set its endpoints.
- ACE_Message_Block *cdr;
-
- ACE_NEW (cdr,
- ACE_Message_Block (end - begin));
-
- cdr->rd_ptr (begin);
-
- cdr->wr_ptr (end);
-
- // Stick it into the Any. It gets duplicated there.
- any->_tao_replace (tc.in (),
- cdr,
- 0,
- env);
-
- // Now we can release the original.
- ACE_Message_Block::release (cdr);
- }
-
- // If any data is left over, it'd be context values ... else error.
- // We don't support context values, so it's always an error.
-
- // @@ (TAO) support for Contexts??
- if (incoming_->length () != 0)
- {
- ACE_ERROR ((LM_ERROR,
- "UIOP_ServerRequest::arguments - "
- "%d bytes left in buffer\n", incoming_->length ()));
- env.exception (new CORBA::BAD_PARAM ());
- }
-}
-
-// Store the result value. There's either an exception, or a result,
-// but not both of them. Results (and exceptions) can be reported
-// only after the parameter list has been provided (maybe empty).
-
-void
-UIOP_ServerRequest::set_result (const CORBA::Any &value,
- CORBA::Environment &env)
-{
- env.clear ();
-
- // setting a result when another result already exists or if an exception
- // exists is an error
- if (this->retval_ || this->exception_)
- env.exception (new CORBA::BAD_INV_ORDER ());
- else
- {
- this->retval_ = new CORBA::Any (value);
- }
-}
-
-// Store the exception value.
-
-void
-UIOP_ServerRequest::set_exception (const CORBA::Any &value,
- CORBA::Environment &env)
-{
- if (this->retval_ || this->exception_)
- env.exception (new CORBA::BAD_INV_ORDER ());
- else
- {
- // Try to narrow to ForwardRequest
- PortableServer::ForwardRequest_ptr forward_request =
- PortableServer::ForwardRequest::_narrow ((CORBA::Exception *) value.value ());
-
- // If narrowing of exception succeeded
- if (forward_request != 0)
- {
- this->forward_location_ = forward_request->forward_reference;
- this->exception_type_ = TAO_GIOP_USER_EXCEPTION;
- }
- // Normal exception
- else
- {
- this->exception_ = new CORBA::Any (value);
-
- // @@ This cast is not safe, but we haven't implemented the >>=
- // and <<= operators for base exceptions (yet).
- CORBA_Exception* x = (CORBA_Exception*)value.value ();
- if (CORBA_UserException::_narrow (x) != 0)
- this->exception_type_ = TAO_GIOP_USER_EXCEPTION;
- else
- this->exception_type_ = TAO_GIOP_SYSTEM_EXCEPTION;
- }
- }
-}
-
-// this method will be utilized by the DSI servant to marshal outgoing
-// parameters
-
-void
-UIOP_ServerRequest::dsi_marshal (CORBA::Environment &env)
-{
- // NOTE: if "env" is set, it takes precedence over exceptions
- // reported using the mechanism of the ServerRequest. Only system
- // exceptions are reported that way ...
- //
- // XXX Exception reporting is ambiguous; it can be cleaner than
- // this. With both language-mapped and dynamic/explicit reporting
- // mechanisms, one of must be tested "first" ... so an exception
- // reported using the other mechanism could be "lost". Perhaps only
- // the language mapped one should be used for system exceptions.
-
-
- // only if there wasn't any exception, we proceed
- if (this->exception_type_ == TAO_GIOP_NO_EXCEPTION &&
- CORBA::is_nil (this->forward_location_.in ()))
- {
- // ... then send any return value ...
- if (this->retval_)
- {
- CORBA::TypeCode_var tc = this->retval_->type ();
- if (this->retval_->any_owns_data ())
- {
- (void) this->outgoing_->encode (tc.in (), retval_->value (), 0, env);
- }
- else
- {
- TAO_InputCDR cdr (retval_->_tao_get_cdr ());
- (void) this->outgoing_->append (tc.in (), &cdr, env);
- }
- }
-
- // ... Followed by "inout" and "out" parameters, left to right
- if (this->params_)
- {
- for (u_int i = 0;
- i < this->params_->count ();
- i++)
- {
- CORBA::NamedValue_ptr nv = this->params_->item (i, env);
- if (!(nv->flags () & (CORBA::ARG_INOUT|CORBA::ARG_OUT)))
- continue;
-
- CORBA::Any_ptr any = nv->value ();
- CORBA::TypeCode_var tc = any->type ();
- if (any->any_owns_data ())
- {
- (void) this->outgoing_->encode (tc.in (), any->value (), 0, env);
- }
- else
- {
- TAO_InputCDR cdr (any->_tao_get_cdr ());
- (void) this->outgoing_->append (tc.in (), &cdr, env);
- }
- }
- }
- }
-}
-
-#endif /* TAO_HAS_MINIMUM_CORBA */
-
-// Extension
-void
-UIOP_ServerRequest::demarshal (CORBA::Environment &orb_env,
- // ORB related exception reporting
- const TAO_Call_Data_Skel *info,
- // call description
- ...)
-{
- CORBA::ULong i;
- const TAO_Param_Data_Skel *pdp;
- va_list param_vector;
- va_start (param_vector, info);
-
- for (i = 0, pdp = info->params;
- i < info->param_count;
- i++, pdp++)
- {
- void *ptr = va_arg (param_vector, void *);
-
- if ((pdp->mode == CORBA::ARG_IN)
- || (pdp->mode == CORBA::ARG_INOUT))
- {
- // Then just unmarshal the value.
- (void) incoming_->decode (pdp->tc, ptr, 0, orb_env);
- }
-
- if (orb_env.exception ())
- {
- orb_env.print_exception ("ServerRequest::demarshal - parameter decode failed");
- return;
- }
- }
- va_end (param_vector);
-}
-
-// Extension
-
-void
-UIOP_ServerRequest::marshal (CORBA::Environment &orb_env,
- // ORB related exception reporting
- // CORBA::Environment &skel_env,
- // skeleton related exception reporting
- const TAO_Call_Data_Skel *info,
- // call description
- ...)
-{
- // what is "orb_env" and "skel_env"?
- // "skel_env" holds the exception that got raised inside the operation
- // implementation (upcall)
- //
- // "orb_env" is the exception that may have been raised due to things going
- // wrong in the entire dispatch process. These are always system exceptions.
-
- // check if we are inside with an exception. This may have happened
- // since the upcall could have set some exception
-#if 0 /* ASG */
- if (skel_env.exception ())
- {
- // We must increase the "refcnt" on the exception, because it is
- // "owned" by both <skel_env> and (eventually) by the
- // Server_Request.
- CORBA::Exception_ptr exception = skel_env.exception ();
- exception->_incr_refcnt ();
-
- // The Any does not own the because ultimately it will be owned
- // by the Server_Request via the call to "set_exception"
- CORBA::Any any (skel_env.exception ()->_type (), exception);
- this->set_exception (any, orb_env);
- }
-#endif
-
- // Setup a Reply message so that we can marshal all the outgoing parameters
- // into it. If an exception was set, then that gets marshaled into the reply
- // message and we don't do anything after that
- this->init_reply (orb_env);
-
-#if 0 /* ASG */
- // exception? nothing to do after this
- if (orb_env.exception () || skel_env.exception ())
- return;
-#endif
- TAO_CHECK_ENV_RETURN_VOID (orb_env);
-
- CORBA::ULong i;
- const TAO_Param_Data_Skel *pdp;
- va_list param_vector;
- va_start (param_vector, info);
-
- for (i = 0, pdp = info->params;
- i < info->param_count;
- i++, pdp++)
- {
- void *ptr = va_arg (param_vector, void *);
-
- if (pdp->mode == 0)
- {
- // check if the return type is not void
- if (pdp->tc->kind (orb_env) != CORBA::tk_void)
- {
- // Then just marshal the value.
- (void) this->outgoing_->encode (pdp->tc, ptr, 0, orb_env);
- }
- }
- else if ((pdp->mode == CORBA::ARG_INOUT)
- || (pdp->mode == CORBA::ARG_OUT))
- {
- // Then just marshal the value.
- (void) this->outgoing_->encode (pdp->tc, ptr, 0, orb_env);
- }
-
- if (orb_env.exception ())
- {
- orb_env.print_exception ("ServerRequest::marshal - parameter encode failed");
- return;
- }
- }
- va_end (param_vector);
-
-}
-
-void
-UIOP_ServerRequest::init_reply (CORBA::Environment &env)
-{
- // Construct a REPLY header.
- TAO_GIOP::start_message (TAO_GIOP::Reply,
- *this->outgoing_,
- this->orb_core_);
-
- TAO_GIOP_ServiceContextList resp_ctx;
- resp_ctx.length (0);
- *this->outgoing_ << resp_ctx;
- this->outgoing_->write_ulong (this->request_id_);
-
- // Standard exceptions are caught in Connect::handle_input
-
- // Forward exception only.
- if (!CORBA::is_nil (this->forward_location_.in ()))
- {
- this->outgoing_->write_ulong (TAO_GIOP_LOCATION_FORWARD);
-
- CORBA::Object_ptr object_ptr = this->forward_location_.in ();
- if ((*this->outgoing_ << object_ptr) == 0)
- {
- ACE_DEBUG ((LM_DEBUG,
- "ServerRequest::marshal - "
- "encoding forwarded objref failed\n"));
- return;
- }
- }
-
- // Any exception at all.
- else if (this->exception_)
- {
- CORBA::TypeCode_ptr except_tc;
-
- except_tc = this->exception_->type ();
-
- // Finish the GIOP Reply header, then marshal the exception.
- // XXX x->type () someday ...
-
- this->outgoing_->write_ulong (this->exception_type_);
-
- // we use the any's ACE_Message_Block
- TAO_InputCDR cdr (this->exception_->_tao_get_cdr ());
- (void) this->outgoing_->append (except_tc, &cdr, env);
- }
- else // Normal reply
- // First finish the GIOP header ...
- this->outgoing_->write_ulong (TAO_GIOP_NO_EXCEPTION);
-}
-
-CORBA::Object_ptr
-UIOP_ServerRequest::forward_location (void)
-// get the forward_location
-{
- return CORBA::Object::_duplicate (this->forward_location_.in ());
-}
-
-CORBA::ULong
-UIOP_ServerRequest::exception_type (void)
-// get the exception type
-{
- return this->exception_type_;
-}
diff --git a/TAO/tao/UIOP_Server_Request.h b/TAO/tao/UIOP_Server_Request.h
deleted file mode 100644
index 23876c56b35..00000000000
--- a/TAO/tao/UIOP_Server_Request.h
+++ /dev/null
@@ -1,203 +0,0 @@
-// This may look like C, but it's really -*- C++ -*-
-// $Id$
-
-// ============================================================================
-//
-// = LIBRARY
-// TAO
-//
-// = FILENAME
-// Server_Request.h
-//
-// = DESCRIPTION
-// Header file for CORBA's Dynamic Server Skeleton Interface's
-// "Server Request" type. (for UIOP)
-//
-// = AUTHOR
-// Copyright 1994-1995 by Sun Microsystems, Inc. and Chris Cleeland.
-// Modifications by Aniruddha Gokhale based on CORBAv2.2 Feb 98
-// UIOP modifications by Ossama Othman -- Apr 99
-// ============================================================================
-
-#ifndef TAO_UIOP_SERVER_REQUEST_H
-#define TAO_UIOP_SERVER_REQUEST_H
-
-#include "tao/Server_Request.h"
-
-class TAO_Export UIOP_ServerRequest : public CORBA_ServerRequest
-{
- // = TITLE
- // Class representing an UIOP ServerRequest object.
-public:
- // = Initialization and termination methods.
- UIOP_ServerRequest (TAO_InputCDR &input,
- TAO_OutputCDR &output,
- TAO_ORB_Core *orb_core,
- CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
- // Constructor
- UIOP_ServerRequest (CORBA::ULong &request_id,
- CORBA::Boolean &response_expected,
- TAO_ObjectKey &object_key,
- const ACE_CString &operation,
- TAO_OutputCDR &output,
- TAO_ORB_Core *orb_core,
- CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
-
- virtual ~UIOP_ServerRequest (void);
- // Destructor.
-
-#if !defined (TAO_HAS_MINIMUM_CORBA)
-
- // = General ServerRequest operations
- void arguments (CORBA::NVList_ptr &list,
- CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
-
- void set_result (const CORBA::Any &value,
- CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
-
- void set_exception (const CORBA::Any &value,
- CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
-
- virtual void dsi_marshal (CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
- // does the marshaling of outgoing parameters and is used by the DSI based
- // scheme
-
-#endif /* TAO_HAS_MINIMUM_CORBA */
-
- // = Request attributes.
-
- const char *operation (void) const;
- // return the operation name
-
- unsigned int operation_length (void) const;
- // return the legnth of the operation
-
- // CORBA::Context_ptr ctx (void);
- // return the context pointer
-
- // = TAO extensions
-
- CORBA::ORB_ptr orb (void);
- // return the underlying ORB
-
- TAO_POA *oa (void);
- // return the Object Adapter
-
- //
- // = TAO extensions
- // meant to be used internally.
- //
-
- virtual void demarshal (CORBA_Environment &orb_env,
- const TAO_Call_Data_Skel *info,
- ...);
- // demarshal incoming parameters. Used by the SII skeleton (i.e., the IDL
- // compiler generated skeleton)
-
- virtual void marshal (CORBA_Environment &orb_env,
- // CORBA_Environment &skel_env,
- const TAO_Call_Data_Skel *info,
- ...);
- // marshal outgoing parameters and return value. This is used by the SSI
- // i.e., by the IDL compiler generated skeletons.
-
- virtual void init_reply (CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
- // start a Reply message
-
- virtual TAO_InputCDR &incoming (void);
- // Retrieve the incoming stream.
-
- virtual TAO_OutputCDR &outgoing (void);
- // Retrieve the outgoing stream.
-
- virtual CORBA::Boolean response_expected (void) const;
- // is the response expected
-
- virtual CORBA::Principal_ptr principal (void) const;
-
- virtual const TAO_ObjectKey &object_key (void) const;
-
- virtual const TAO_GIOP_ServiceContextList &service_info (void) const;
-
- // The pseudo object methods, not really needed because the class is
- // not in the spec, but we add them for the sake of completeness.
- static UIOP_ServerRequest* _duplicate (UIOP_ServerRequest*);
- static UIOP_ServerRequest* _nil (void);
-
- // To handle System Exceptions at the lowest level,
- // a method returning the request_id_ is needed.
-
- CORBA::ULong request_id (void);
-
- CORBA::Object_ptr forward_location (void);
- // get the forward_location
-
- CORBA::ULong exception_type (void);
- // get the exception type
-
-private:
- void parse_header (CORBA::Environment &TAO_IN_ENV);
- // Parse the request header and store the result on this object.
-
- void parse_header_std (CORBA::Environment &TAO_IN_ENV);
- // Parse the standard UIOP request header and store the result on
- // this object.
-
- void parse_header_lite (CORBA::Environment &TAO_IN_ENV);
- // Parse the lightweight version of the UIOP request header and
- // store the result on this object.
-
-private:
- ACE_CString operation_;
- // Operation name.
-
- CORBA::Object_var forward_location_;
-
- TAO_InputCDR *incoming_;
- // Incoming stream.
-
- TAO_OutputCDR *outgoing_;
- // Outgoing stream.
-
- CORBA::Boolean response_expected_;
- // is it oneway or twoway
-
-#if !defined (TAO_HAS_MINIMUM_CORBA)
-
- CORBA::NVList_ptr params_;
- // Incoming parameters.
-
-#endif /* TAO_HAS_MINIMUM_CORBA */
-
- CORBA::Any_ptr retval_;
- // Return value.
-
- CORBA::Any_ptr exception_;
- // Any exception which might be raised.
-
- // TAO_GIOP_ReplyStatusType exception_type_;
- CORBA::ULong exception_type_;
- // exception type (will be NO_EXCEPTION in the majority of the cases)
-
- TAO_ORB_Core* orb_core_;
- // A pointer to the ORB Core for the context where the request was
- // created.
-
- TAO_GIOP_ServiceContextList service_info_;
- // The service context for the request (CORBA Reference?)
-
- CORBA::ULong request_id_;
- // Unique identifier for a request
-
- TAO_ObjectKey object_key_;
- // The object key of the destination object.
-
- CORBA::Principal_ptr requesting_principal_;
- // Identifies the requester
-};
-
-#if defined (__ACE_INLINE__)
-# include "tao/UIOP_Server_Request.i"
-#endif /* __ACE_INLINE__ */
-
-#endif /* TAO_UIOP_SERVER_REQUEST_H */
diff --git a/TAO/tao/IIOP_Server_Request.cpp b/TAO/tao/GIOP_Server_Request.cpp
index 973078a8656..35d5f0cce36 100644
--- a/TAO/tao/IIOP_Server_Request.cpp
+++ b/TAO/tao/GIOP_Server_Request.cpp
@@ -1,8 +1,8 @@
// $Id$
// Implementation of the Dynamic Server Skeleton Interface (for IIOP)
#include "tao/IIOP_Server_Request.h"
#include "tao/CDR.h"
#include "tao/POAC.h"
@@ -14,17 +14,17 @@
#include "tao/Any.h"
#if !defined (__ACE_INLINE__)
-# include "tao/IIOP_Server_Request.i"
+# include "tao/GIOP_Server_Request.i"
#endif /* ! __ACE_INLINE__ */
-ACE_RCSID(tao, IIOP_Server_Request, "$Id$")
+ACE_RCSID(tao, GIOP_Server_Request, "$Id$")
#if defined (ACE_ENABLE_TIMEPROBES)
static const char *TAO_Server_Request_Timeprobe_Description[] =
{
- "Server_Request::Server_Request - start",
- "Server_Request::Server_Request - end",
+ "GIOP_Server_Request::GIOP_Server_Request - start",
+ "GIOP_Server_Request::GIOP_Server_Request - end",
};
enum
@@ -40,7 +40,7 @@ ACE_TIMEPROBE_EVENT_DESCRIPTIONS (TAO_Server_Request_Timeprobe_Description,
#endif /* ACE_ENABLE_TIMEPROBES */
-IIOP_ServerRequest::IIOP_ServerRequest (TAO_InputCDR &input,
+GIOP_ServerRequest::GIOP_ServerRequest (TAO_InputCDR &input,
TAO_OutputCDR &output,
TAO_ORB_Core *orb_core,
CORBA::Environment &env)
@@ -69,7 +69,7 @@ IIOP_ServerRequest::IIOP_ServerRequest (TAO_InputCDR &input,
}
void
-IIOP_ServerRequest::parse_header_std (CORBA::Environment &ACE_TRY_ENV)
+GIOP_ServerRequest::parse_header_std (CORBA::Environment &ACE_TRY_ENV)
{
// Tear out the service context ... we currently ignore it, but it
// should probably be passed to each ORB service as appropriate
@@ -127,7 +127,7 @@ IIOP_ServerRequest::parse_header_std (CORBA::Environment &ACE_TRY_ENV)
}
void
-IIOP_ServerRequest::parse_header_lite (CORBA::Environment &ACE_TRY_ENV)
+GIOP_ServerRequest::parse_header_lite (CORBA::Environment &ACE_TRY_ENV)
{
TAO_InputCDR& input = *this->incoming_;
@@ -170,7 +170,7 @@ IIOP_ServerRequest::parse_header_lite (CORBA::Environment &ACE_TRY_ENV)
void
-IIOP_ServerRequest::parse_header (CORBA::Environment &env)
+GIOP_ServerRequest::parse_header (CORBA::Environment &env)
{
if (this->orb_core_->orb_params ()->use_lite_protocol ())
this->parse_header_lite (env);
@@ -180,7 +180,7 @@ IIOP_ServerRequest::parse_header (CORBA::Environment &env)
// This constructor is used, by the locate request code
-IIOP_ServerRequest::IIOP_ServerRequest (CORBA::ULong &request_id,
+GIOP_ServerRequest::GIOP_ServerRequest (CORBA::ULong &request_id,
CORBA::Boolean &response_expected,
TAO_ObjectKey &object_key,
const ACE_CString &operation,
@@ -209,7 +209,7 @@ IIOP_ServerRequest::IIOP_ServerRequest (CORBA::ULong &request_id,
{
}
-IIOP_ServerRequest::~IIOP_ServerRequest (void)
+GIOP_ServerRequest::~GIOP_ServerRequest (void)
{
#if !defined (TAO_HAS_MINIMUM_CORBA)
@@ -224,13 +224,13 @@ IIOP_ServerRequest::~IIOP_ServerRequest (void)
}
CORBA::ORB_ptr
-IIOP_ServerRequest::orb (void)
+GIOP_ServerRequest::orb (void)
{
return this->orb_core_->orb ();
}
TAO_POA *
-IIOP_ServerRequest::oa (void)
+GIOP_ServerRequest::oa (void)
{
return this->orb_core_->root_poa ();
}
@@ -241,7 +241,7 @@ IIOP_ServerRequest::oa (void)
// inout/out/return values later on.
void
-IIOP_ServerRequest::arguments (CORBA::NVList_ptr &list,
+GIOP_ServerRequest::arguments (CORBA::NVList_ptr &list,
CORBA::Environment &env)
{
env.clear ();
@@ -280,7 +280,7 @@ IIOP_ServerRequest::arguments (CORBA::NVList_ptr &list,
param_name = "(no name given)";
ACE_ERROR ((LM_ERROR,
- "IIOP_ServerRequest::arguments - problem while"
+ "GIOP_ServerRequest::arguments - problem while"
" decoding parameter %d <%s>\n", i, param_name));
return;
}
@@ -315,7 +315,7 @@ IIOP_ServerRequest::arguments (CORBA::NVList_ptr &list,
if (incoming_->length () != 0)
{
ACE_ERROR ((LM_ERROR,
- "IIOP_ServerRequest::arguments - "
+ "GIOP_ServerRequest::arguments - "
"%d bytes left in buffer\n", incoming_->length ()));
env.exception (new CORBA::BAD_PARAM ());
}
@@ -326,7 +326,7 @@ IIOP_ServerRequest::arguments (CORBA::NVList_ptr &list,
// only after the parameter list has been provided (maybe empty).
void
-IIOP_ServerRequest::set_result (const CORBA::Any &value,
+GIOP_ServerRequest::set_result (const CORBA::Any &value,
CORBA::Environment &env)
{
env.clear ();
@@ -344,7 +344,7 @@ IIOP_ServerRequest::set_result (const CORBA::Any &value,
// Store the exception value.
void
-IIOP_ServerRequest::set_exception (const CORBA::Any &value,
+GIOP_ServerRequest::set_exception (const CORBA::Any &value,
CORBA::Environment &env)
{
if (this->retval_ || this->exception_)
@@ -381,7 +381,7 @@ IIOP_ServerRequest::set_exception (const CORBA::Any &value,
// parameters
void
-IIOP_ServerRequest::dsi_marshal (CORBA::Environment &env)
+GIOP_ServerRequest::dsi_marshal (CORBA::Environment &env)
{
// NOTE: if "env" is set, it takes precedence over exceptions
// reported using the mechanism of the ServerRequest. Only system
@@ -444,7 +444,7 @@ IIOP_ServerRequest::dsi_marshal (CORBA::Environment &env)
// Extension
void
-IIOP_ServerRequest::demarshal (CORBA::Environment &orb_env,
+GIOP_ServerRequest::demarshal (CORBA::Environment &orb_env,
// ORB related exception reporting
const TAO_Call_Data_Skel *info,
// call description
@@ -470,7 +470,7 @@ IIOP_ServerRequest::demarshal (CORBA::Environment &orb_env,
if (orb_env.exception ())
{
- orb_env.print_exception ("ServerRequest::demarshal - parameter decode failed");
+ orb_env.print_exception ("GIOP_ServerRequest::demarshal - parameter decode failed");
return;
}
}
@@ -480,7 +480,7 @@ IIOP_ServerRequest::demarshal (CORBA::Environment &orb_env,
// Extension
void
-IIOP_ServerRequest::marshal (CORBA::Environment &orb_env,
+GIOP_ServerRequest::marshal (CORBA::Environment &orb_env,
// ORB related exception reporting
// CORBA::Environment &skel_env,
// skeleton related exception reporting
@@ -554,7 +554,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &orb_env,
if (orb_env.exception ())
{
- orb_env.print_exception ("ServerRequest::marshal - parameter encode failed");
+ orb_env.print_exception ("GIOP_ServerRequest::marshal - parameter encode failed");
return;
}
}
@@ -563,7 +563,7 @@ IIOP_ServerRequest::marshal (CORBA::Environment &orb_env,
}
void
-IIOP_ServerRequest::init_reply (CORBA::Environment &env)
+GIOP_ServerRequest::init_reply (CORBA::Environment &env)
{
// Construct a REPLY header.
TAO_GIOP::start_message (TAO_GIOP::Reply,
@@ -586,7 +586,7 @@ IIOP_ServerRequest::init_reply (CORBA::Environment &env)
if ((*this->outgoing_ << object_ptr) == 0)
{
ACE_DEBUG ((LM_DEBUG,
- "ServerRequest::marshal - "
+ "GIOP_ServerRequest::marshal - "
"encoding forwarded objref failed\n"));
return;
}
@@ -614,14 +614,14 @@ IIOP_ServerRequest::init_reply (CORBA::Environment &env)
}
CORBA::Object_ptr
-IIOP_ServerRequest::forward_location (void)
+GIOP_ServerRequest::forward_location (void)
// get the forward_location
{
return CORBA::Object::_duplicate (this->forward_location_.in ());
}
CORBA::ULong
-IIOP_ServerRequest::exception_type (void)
+GIOP_ServerRequest::exception_type (void)
// get the exception type
{
return this->exception_type_;
@@ -1,8 +1,8 @@
// $Id$
-// Implementation of the Dynamic Server Skeleton Interface (for IIOP)
+// Implementation of the Dynamic Server Skeleton Interface (for GIOP)
-#include "tao/IIOP_Server_Request.h"
+#include "tao/GIOP_Server_Request.h"
#include "tao/CDR.h"
#include "tao/POAC.h"
diff --git a/TAO/tao/IIOP_Server_Request.h b/TAO/tao/GIOP_Server_Request.h
index ba7c9d9353c..84d99c95c82 100644
--- a/TAO/tao/IIOP_Server_Request.h
+++ b/TAO/tao/GIOP_Server_Request.h
@@ -7,34 +7,34 @@
// TAO
//
// = FILENAME
-// IIOP_Server_Request.h
+// GIOP_Server_Request.h
//
// = DESCRIPTION
// Header file for CORBA's Dynamic Server Skeleton Interface's
-// "Server Request" type. (for IIOP)
+// "Server Request" type. (for GIOP)
//
// = AUTHOR
// Copyright 1994-1995 by Sun Microsystems, Inc. and Chris Cleeland.
// Modifications by Aniruddha Gokhale based on CORBAv2.2 Feb 98
// ============================================================================
-#ifndef TAO_IIOP_SERVER_REQUEST_H
-#define TAO_IIOP_SERVER_REQUEST_H
+#ifndef TAO_GIOP_SERVER_REQUEST_H
+#define TAO_GIOP_SERVER_REQUEST_H
#include "tao/Server_Request.h"
-class TAO_Export IIOP_ServerRequest : public CORBA_ServerRequest
+class TAO_Export GIOP_ServerRequest : public CORBA_ServerRequest
{
// = TITLE
// Class representing an IIOP ServerRequest object.
public:
// = Initialization and termination methods.
- IIOP_ServerRequest (TAO_InputCDR &input,
+ GIOP_ServerRequest (TAO_InputCDR &input,
TAO_OutputCDR &output,
TAO_ORB_Core *orb_core,
CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
// Constructor
- IIOP_ServerRequest (CORBA::ULong &request_id,
+ GIOP_ServerRequest (CORBA::ULong &request_id,
CORBA::Boolean &response_expected,
TAO_ObjectKey &object_key,
const ACE_CString &operation,
@@ -42,7 +42,7 @@ public:
TAO_ORB_Core *orb_core,
CORBA_Environment &TAO_IN_ENV = CORBA::default_environment ());
- virtual ~IIOP_ServerRequest (void);
+ virtual ~GIOP_ServerRequest (void);
// Destructor.
#if !defined (TAO_HAS_MINIMUM_CORBA)
@@ -120,8 +120,8 @@ public:
// The pseudo object methods, not really needed because the class is
// not in the spec, but we add them for the sake of completeness.
- static IIOP_ServerRequest* _duplicate (IIOP_ServerRequest*);
- static IIOP_ServerRequest* _nil (void);
+ static GIOP_ServerRequest* _duplicate (GIOP_ServerRequest*);
+ static GIOP_ServerRequest* _nil (void);
// To handle System Exceptions at the lowest level,
// a method returning the request_id_ is needed.
@@ -139,11 +139,11 @@ private:
// Parse the request header and store the result on this object.
void parse_header_std (CORBA::Environment &TAO_IN_ENV);
// Parse the standard IIOP request header and store the result on
// this object.
void parse_header_lite (CORBA::Environment &TAO_IN_ENV);
// Parse the lightweight version of the IIOP request header and
// store the result on this object.
private:
@@ -196,7 +196,7 @@ private:
};
#if defined (__ACE_INLINE__)
-# include "tao/IIOP_Server_Request.i"
+# include "tao/GIOP_Server_Request.i"
#endif /* __ACE_INLINE__ */
-#endif /* TAO_IIOP_SERVER_REQUEST_H */
+#endif /* TAO_GIOP_SERVER_REQUEST_H */
@@ -7,34 +7,34 @@
{
// = TITLE
- // Class representing an IIOP ServerRequest object.
+ // Class representing an GIOP ServerRequest object.
public:
// = Initialization and termination methods.
@@ -139,11 +139,11 @@ private:
// Parse the request header and store the result on this object.
void parse_header_std (CORBA::Environment &TAO_IN_ENV);
- // Parse the standard IIOP request header and store the result on
+ // Parse the standard GIOP request header and store the result on
// this object.
void parse_header_lite (CORBA::Environment &TAO_IN_ENV);
@@ -139,11 +139,11 @@ private:
// this object.
void parse_header_lite (CORBA::Environment &TAO_IN_ENV);
- // Parse the lightweight version of the IIOP request header and
+ // Parse the lightweight version of the GIOP request header and
// store the result on this object.
private: